@@ -3,7 +3,7 @@ package Acme::CPANModules::BrowsingTableInteractively;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-04-25'; # DATE
 our $DIST = 'Acme-CPANModules-BrowsingTableInteractively'; # DIST
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use strict;
 use Acme::CPANModulesUtil::Misc;
@@ -21,14 +21,14 @@ horizontal scrolling support or a way to see long text in a column. Not updated
 since 2016.
 
 <pm:Term::TablePrint> - this module lets you browse the table in a terminal.
-Roughly provides the same features like Tickit::Table::Widget with an extra one:
+Provides roughly the same features like Tickit::Table::Widget with an extra one:
 you can press Enter on a row to view it as a "card" where each column will be
 displayed vertically, so you can better see a row that has many columns or
 columns with long text.
 
 Personally, both the above modules are not satisfactory for me. They are not
 that much better than drawing the text table and then filtering the output
-through a pager like *less*. At least with `less` you can scroll horizontally or
+through a pager like *less*. At least with *less* you can scroll horizontally or
 perform incremental searching (though not interactive filtering of rows).
 
 <pm:Text::Table::HTML::DataTables> - this module bundles the wonderful
@@ -40,12 +40,12 @@ hide/show/reorder columns, change the page size, and so on. This is leaps and
 bounds more useful than simply scrolling pages of text provided by
 Tickit::Table::Widget or Term::TablePrint.
 
-[1] https://datatables.net/
+[1] <https://datatables.net/>
 
 _
 
 our $LIST = {
-    summary => 'Creating a palette of visually distinct colors',
+    summary => 'Browsing table interactively',
     description => $text,
     tags => ['task'],
 };
@@ -53,7 +53,7 @@ our $LIST = {
 Acme::CPANModulesUtil::Misc::populate_entries_from_module_links_in_description;
 
 1;
-# ABSTRACT: Creating a palette of visually distinct colors
+# ABSTRACT: Browsing table interactively
 
 __END__
 
@@ -63,11 +63,11 @@ __END__
 
 =head1 NAME
 
-Acme::CPANModules::BrowsingTableInteractively - Creating a palette of visually distinct colors
+Acme::CPANModules::BrowsingTableInteractively - Browsing table interactively
 
 =head1 VERSION
 
-This document describes version 0.001 of Acme::CPANModules::BrowsingTableInteractively (from Perl distribution Acme-CPANModules-BrowsingTableInteractively), released on 2021-04-25.
+This document describes version 0.002 of Acme::CPANModules::BrowsingTableInteractively (from Perl distribution Acme-CPANModules-BrowsingTableInteractively), released on 2021-04-25.
 
 =head1 DESCRIPTION
 
@@ -82,14 +82,14 @@ horizontal scrolling support or a way to see long text in a column. Not updated
 since 2016.
 
 L<Term::TablePrint> - this module lets you browse the table in a terminal.
-Roughly provides the same features like Tickit::Table::Widget with an extra one:
+Provides roughly the same features like Tickit::Table::Widget with an extra one:
 you can press Enter on a row to view it as a "card" where each column will be
 displayed vertically, so you can better see a row that has many columns or
 columns with long text.
 
 Personally, both the above modules are not satisfactory for me. They are not
 that much better than drawing the text table and then filtering the output
-through a pager like I<less>. At least with C<less> you can scroll horizontally or
+through a pager like I<less>. At least with I<less> you can scroll horizontally or
 perform incremental searching (though not interactive filtering of rows).
 
 L<Text::Table::HTML::DataTables> - this module bundles the wonderful
@@ -101,9 +101,9 @@ hide/show/reorder columns, change the page size, and so on. This is leaps and
 bounds more useful than simply scrolling pages of text provided by
 Tickit::Table::Widget or Term::TablePrint.
 
-[1] https://datatables.net/
+[1] L<https://datatables.net/>
 
-=head1 ACME::CPANMODULES ENTRIES
+=head1 MODULES INCLUDED IN THIS ACME::CPANMODULES MODULE
 
 =over
 
@@ -119,12 +119,6 @@ Tickit::Table::Widget or Term::TablePrint.
 
 =head1 FAQ
 
-=head2 What is an Acme::CPANModules::* module?
-
-An Acme::CPANModules::* module, like this module, contains just a list of module
-names that share a common characteristics. It is a way to categorize modules and
-document CPAN. See L<Acme::CPANModules> for more details.
-
 =head2 What are ways to use this Acme::CPANModules module?
 
 Aside from reading this Acme::CPANModules module's POD documentation, you can
@@ -155,7 +149,7 @@ Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModules-Bro
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Acme-CPANModules-BrowsingTableInteractively/issues>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModules-BrowsingTableInteractively>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
